Coverage for pygeodesy/triaxials/__init__.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''Package of lazily imported modules L{triaxials.conformal3}, L{triaxials.triaxial3}

5 and L{triaxials.triaxial5} for triaxial ellipsoids.

6

7 Mostly transcoded to pure Python from I{Karney}'s U{GeographicLib 2.7 Triaxial<https://

8 GeographicLib.SourceForge.io/C++/doc/namespaceGeographicLib_1_1Triaxial.html} classes

9 and the I{experimental} U{GeographicLib 2.52 Jacobi<https://GeographicLib.SourceForge.io/

10 C++/2.5.2/jacobi.html>} class.

11

12 Copyright (C) U{Charles Karney<mailto:Karney@Alum.MIT.edu>} (2008-2024, 2024-2025) and

13 licensed under the MIT/X11 License. For more information, see the U{GeographicLib 2.5.2

14 and 2.7<https://GeographicLib.SourceForge.io>} documentation.

15'''

16 from pygeodesy.lazily import _ALL_LAZY, _ALL_OTHER, _lazy_import_as, _unLazy0

17# from pygeodesy.triaxials.triaxial5 import * # PYCHOK for backward compatibility

18# from pygeodesy.triaxials.bases import TriaxialError # likewise

19

20 __all__ = _ALL_LAZY.triaxials # _triaxial5 # likewise

21 __version__ = '26.02.06'

22

23 if _unLazy0: # or _isfrozen

24 from pygeodesy.triaxials.bases import LLK, TriaxialError

25 from pygeodesy.triaxials.conformal3 import BetOmgGam5Tuple, Conformal3, Conformal3B, \

26 Conformal3Sphere, Conformal5Tuple

27 from pygeodesy.triaxials.triaxial3 import BetOmgAlp5Tuple, Cartesian5Tuple, PhiLamZet5Tuple, \

28 Triaxial3, Triaxial3B, Triaxial3s

29 from pygeodesy.triaxials.triaxial5 import BetaOmega2Tuple, BetaOmega3Tuple, \

30 Conformal, ConformalSphere, Conformal2Tuple, \

31 Triaxial, Triaxial_, Triaxials, \

32 hartzell4, height4

33

34 __all__ += _ALL_OTHER(LLK, TriaxialError,

35 BetOmgGam5Tuple, Conformal3, Conformal3B, ConformalSphere,

36 Conformal5Tuple,

37 BetOmgAlp5Tuple, Cartesian5Tuple, PhiLamZet5Tuple,

38 Triaxial3, Triaxial3B, Triaxial3s,

39 BetaOmega2Tuple, BetaOmega3Tuple,

40 Conformal, Conformal3Sphere, Conformal2Tuple, Triaxial,

41 Triaxial_, Triaxials, hartzell4, height4)

42# assert set(_ALL_LAZY.triaxials + _ALL_LAZY.triaxials_bases

43# + _ALL_LAZY.triaxials_conformal3

44# + _ALL_LAZY.triaxials_triaxial3

45# + _ALL_LAZY.triaxials_triaxial5) == set(__all__)

46

47 else: # lazily import modules and exported attrs

48 __getattr__ = _lazy_import_as(__name__)

49

50# **) MIT License

51#

52# Copyright (C) 2025-2026 -- mrJean1 at Gmail -- All Rights Reserved.

53#

54# Permission is hereby granted, free of charge, to any person obtaining a

55# copy of this software and associated documentation files (the "Software"),

56# to deal in the Software without restriction, including without limitation

57# the rights to use, copy, modify, merge, publish, distribute, sublicense,

58# and/or sell copies of the Software, and to permit persons to whom the

59# Software is furnished to do so, subject to the following conditions:

60#

61# The above copyright notice and this permission notice shall be included

62# in all copies or substantial portions of the Software.

63#

64# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

65# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

66# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

67# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

68# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

69# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

70# OTHER DEALINGS IN THE SOFTWARE.